pub struct InstanceState { /* private fields */ }Implementations
Sourceimpl InstanceState
impl InstanceState
Sourcepub fn set_self_request_origin(&mut self, origin: SelfRequestOrigin)
pub fn set_self_request_origin(&mut self, origin: SelfRequestOrigin)
Sets the SelfRequestOrigin for this instance.
This is used to handle outbound requests to relative URLs. If unset, those requests will fail.
Sourcepub fn set_request_interceptor(
&mut self,
interceptor: impl OutboundHttpInterceptor + 'static,
) -> Result<()>
pub fn set_request_interceptor( &mut self, interceptor: impl OutboundHttpInterceptor + 'static, ) -> Result<()>
Sets a OutboundHttpInterceptor for this instance.
Returns an error if it has already been called for this instance.